@@ -3,8 +3,8 @@
 
 #include <glib-object.h>
 
-/* enumerations from "/usr/src/ports/engrampa/engrampa-1.10.1-1.x86_64/src/engrampa-1.10.1/src/typedefs.h" */
-#include "/usr/src/ports/engrampa/engrampa-1.10.1-1.x86_64/src/engrampa-1.10.1/src/typedefs.h"
+/* enumerations from "/usr/src/ports/engrampa/engrampa-1.18.1-1.i686/src/engrampa-1.18.1/src/typedefs.h" */
+#include "/usr/src/ports/engrampa/engrampa-1.18.1-1.i686/src/engrampa-1.18.1/src/typedefs.h"
 GType
 fr_compression_get_type (void)
 {
