@@ -50,9 +50,9 @@
 #endif /* !G_ENABLE_DEBUG */
 
 
-/* VOID:INT (/usr/src/ports/engrampa/engrampa-1.10.1-1.x86_64/src/engrampa-1.10.1/src/fr-marshal.list:1) */
+/* VOID:INT (/usr/src/ports/engrampa/engrampa-1.18.1-1.i686/src/engrampa-1.18.1/src/fr-marshal.list:1) */
 
-/* VOID:INT,INT (/usr/src/ports/engrampa/engrampa-1.10.1-1.x86_64/src/engrampa-1.10.1/src/fr-marshal.list:2) */
+/* VOID:INT,INT (/usr/src/ports/engrampa/engrampa-1.18.1-1.i686/src/engrampa-1.18.1/src/fr-marshal.list:2) */
 void
 fr_marshal_VOID__INT_INT (GClosure     *closure,
                           GValue       *return_value G_GNUC_UNUSED,
@@ -65,9 +65,9 @@ fr_marshal_VOID__INT_INT (GClosure     *closure,
                                               gint         arg_1,
                                               gint         arg_2,
                                               gpointer     data2);
-  register GMarshalFunc_VOID__INT_INT callback;
-  register GCClosure *cc = (GCClosure*) closure;
-  register gpointer data1, data2;
+  GMarshalFunc_VOID__INT_INT callback;
+  GCClosure *cc = (GCClosure*) closure;
+  gpointer data1, data2;
 
   g_return_if_fail (n_param_values == 3);
 
@@ -89,7 +89,7 @@ fr_marshal_VOID__INT_INT (GClosure     *closure,
             data2);
 }
 
-/* VOID:INT,BOXED (/usr/src/ports/engrampa/engrampa-1.10.1-1.x86_64/src/engrampa-1.10.1/src/fr-marshal.list:3) */
+/* VOID:INT,BOXED (/usr/src/ports/engrampa/engrampa-1.18.1-1.i686/src/engrampa-1.18.1/src/fr-marshal.list:3) */
 void
 fr_marshal_VOID__INT_BOXED (GClosure     *closure,
                             GValue       *return_value G_GNUC_UNUSED,
@@ -102,9 +102,9 @@ fr_marshal_VOID__INT_BOXED (GClosure     *closure,
                                                 gint         arg_1,
                                                 gpointer     arg_2,
                                                 gpointer     data2);
-  register GMarshalFunc_VOID__INT_BOXED callback;
-  register GCClosure *cc = (GCClosure*) closure;
-  register gpointer data1, data2;
+  GMarshalFunc_VOID__INT_BOXED callback;
+  GCClosure *cc = (GCClosure*) closure;
+  gpointer data1, data2;
 
   g_return_if_fail (n_param_values == 3);
 
@@ -126,13 +126,13 @@ fr_marshal_VOID__INT_BOXED (GClosure     *closure,
             data2);
 }
 
-/* VOID:POINTER (/usr/src/ports/engrampa/engrampa-1.10.1-1.x86_64/src/engrampa-1.10.1/src/fr-marshal.list:4) */
+/* VOID:POINTER (/usr/src/ports/engrampa/engrampa-1.18.1-1.i686/src/engrampa-1.18.1/src/fr-marshal.list:4) */
 
-/* VOID:VOID (/usr/src/ports/engrampa/engrampa-1.10.1-1.x86_64/src/engrampa-1.10.1/src/fr-marshal.list:5) */
+/* VOID:VOID (/usr/src/ports/engrampa/engrampa-1.18.1-1.i686/src/engrampa-1.18.1/src/fr-marshal.list:5) */
 
-/* VOID:DOUBLE (/usr/src/ports/engrampa/engrampa-1.10.1-1.x86_64/src/engrampa-1.10.1/src/fr-marshal.list:6) */
+/* VOID:DOUBLE (/usr/src/ports/engrampa/engrampa-1.18.1-1.i686/src/engrampa-1.18.1/src/fr-marshal.list:6) */
 
-/* VOID:DOUBLE,STRING (/usr/src/ports/engrampa/engrampa-1.10.1-1.x86_64/src/engrampa-1.10.1/src/fr-marshal.list:7) */
+/* VOID:DOUBLE,STRING (/usr/src/ports/engrampa/engrampa-1.18.1-1.i686/src/engrampa-1.18.1/src/fr-marshal.list:7) */
 void
 fr_marshal_VOID__DOUBLE_STRING (GClosure     *closure,
                                 GValue       *return_value G_GNUC_UNUSED,
@@ -145,9 +145,9 @@ fr_marshal_VOID__DOUBLE_STRING (GClosure     *closure,
                                                     gdouble      arg_1,
                                                     gpointer     arg_2,
                                                     gpointer     data2);
-  register GMarshalFunc_VOID__DOUBLE_STRING callback;
-  register GCClosure *cc = (GCClosure*) closure;
-  register gpointer data1, data2;
+  GMarshalFunc_VOID__DOUBLE_STRING callback;
+  GCClosure *cc = (GCClosure*) closure;
+  gpointer data1, data2;
 
   g_return_if_fail (n_param_values == 3);
 
@@ -169,9 +169,9 @@ fr_marshal_VOID__DOUBLE_STRING (GClosure     *closure,
             data2);
 }
 
-/* VOID:STRING (/usr/src/ports/engrampa/engrampa-1.10.1-1.x86_64/src/engrampa-1.10.1/src/fr-marshal.list:8) */
+/* VOID:STRING (/usr/src/ports/engrampa/engrampa-1.18.1-1.i686/src/engrampa-1.18.1/src/fr-marshal.list:8) */
 
-/* VOID:BOOL (/usr/src/ports/engrampa/engrampa-1.10.1-1.x86_64/src/engrampa-1.10.1/src/fr-marshal.list:9) */
+/* VOID:BOOL (/usr/src/ports/engrampa/engrampa-1.18.1-1.i686/src/engrampa-1.18.1/src/fr-marshal.list:9) */
 
-/* VOID:BOXED (/usr/src/ports/engrampa/engrampa-1.10.1-1.x86_64/src/engrampa-1.10.1/src/fr-marshal.list:10) */
+/* VOID:BOXED (/usr/src/ports/engrampa/engrampa-1.18.1-1.i686/src/engrampa-1.18.1/src/fr-marshal.list:10) */
 
